==> naiveproxy-136.0.7103.44-1.tar.gz: naiveproxy-136.0.7103.44-1/src/net/base/address_tracker_linux_test_util.h <==
// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef NET_BASE_ADDRESS_TRACKER_LINUX_TEST_UTIL_H_
#define NET_BASE_ADDRESS_TRACKER_LINUX_TEST_UTIL_H_

#ifdef UNSAFE_BUFFERS_BUILD
// TODO(crbug.com/374320451): Fix and remove.
#pragma allow_unsafe_buffers
#endif

#include <linux/netlink.h>
#include <linux/rtnetlink.h>
#include <stdint.h>

#include <cstddef>
#include <vector>

bool operator==(const struct ifaddrmsg& lhs, const struct ifaddrmsg& rhs);

namespace net {
class IPAddress;
}

namespace net::test {

using NetlinkBuffer = std::vector<char>;

class NetlinkMessage {
 public:
  explicit NetlinkMessage(uint16_t type);
  ~NetlinkMessage();
  void AddPayload(const void* data, size_t length);
  template <typename T>
  void AddPayload(const T& data) {
    AddPayload(&data, sizeof(data));
  }
  void AddAttribute(uint16_t type, const void* data, size_t length);
  void AppendTo(NetlinkBuffer* output) const;

 private:
  void Append(const void* data, size_t length);
  void Align();
  struct nlmsghdr* header() {
    return reinterpret_cast<struct nlmsghdr*>(buffer_.data());
  }

  NetlinkBuffer buffer_;
};

void MakeAddrMessageWithCacheInfo(uint16_t type,
                                  uint8_t flags,
                                  uint8_t family,
                                  int index,
                                  const IPAddress& address,
                                  const IPAddress& local,
                                  uint32_t preferred_lifetime,
                                  NetlinkBuffer* output);

void MakeAddrMessage(uint16_t type,
                     uint8_t flags,
                     uint8_t family,
                     int index,
                     const IPAddress& address,
                     const IPAddress& local,
                     NetlinkBuffer* output);

void MakeLinkMessage(uint16_t type,
                     uint32_t flags,
                     uint32_t index,
                     NetlinkBuffer* output,
                     bool clear_output = true);

void MakeWirelessLinkMessage(uint16_t type,
                             uint32_t flags,
                             uint32_t index,
                             NetlinkBuffer* output,
                             bool clear_output = true);
}  // namespace net::test

#endif  // NET_BASE_ADDRESS_TRACKER_LINUX_TEST_UTIL_H_

==> naiveproxy-138.0.7204.35-1.tar.gz: naiveproxy-138.0.7204.35-1/src/net/base/address_tracker_linux_test_util.h <==
// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef NET_BASE_ADDRESS_TRACKER_LINUX_TEST_UTIL_H_
#define NET_BASE_ADDRESS_TRACKER_LINUX_TEST_UTIL_H_

#include <linux/netlink.h>
#include <linux/rtnetlink.h>
#include <stdint.h>

#include <cstddef>
#include <vector>

#include "base/compiler_specific.h"
#include "base/containers/span.h"

bool operator==(const struct ifaddrmsg& lhs, const struct ifaddrmsg& rhs);

namespace net {
class IPAddress;
}

namespace net::test {

using NetlinkBuffer = std::vector<char>;

class NetlinkMessage {
 public:
  explicit NetlinkMessage(uint16_t type);
  ~NetlinkMessage();
  void AddPayload(base::span<const uint8_t> data);
  void AddAttribute(uint16_t type, base::span<const uint8_t> data);
  void AppendTo(NetlinkBuffer* output) const;

 private:
  void Append(base::span<const uint8_t> data);
  void Align();
  nlmsghdr* header() {
    return UNSAFE_TODO(reinterpret_cast<nlmsghdr*>(buffer_.data()));
  }

  NetlinkBuffer buffer_;
};

void MakeAddrMessageWithCacheInfo(uint16_t type,
                                  uint8_t flags,
                                  uint8_t family,
                                  int index,
                                  const IPAddress& address,
                                  const IPAddress& local,
                                  uint32_t preferred_lifetime,
                                  NetlinkBuffer* output);

void MakeAddrMessage(uint16_t type,
                     uint8_t flags,
                     uint8_t family,
                     int index,
                     const IPAddress& address,
                     const IPAddress& local,
                     NetlinkBuffer* output);

void MakeLinkMessage(uint16_t type,
                     uint32_t flags,
                     uint32_t index,
                     NetlinkBuffer* output,
                     bool clear_output = true);

void MakeWirelessLinkMessage(uint16_t type,
                             uint32_t flags,
                             uint32_t index,
                             NetlinkBuffer* output,
                             bool clear_output = true);
}  // namespace net::test

#endif  // NET_BASE_ADDRESS_TRACKER_LINUX_TEST_UTIL_H_
